summaryrefslogtreecommitdiff
path: root/src/conf_mode/qos.py
diff options
context:
space:
mode:
Diffstat (limited to 'src/conf_mode/qos.py')
-rwxr-xr-xsrc/conf_mode/qos.py7
1 files changed, 3 insertions, 4 deletions
diff --git a/src/conf_mode/qos.py b/src/conf_mode/qos.py
index 2b4fcc1bf..818f9a7ac 100755
--- a/src/conf_mode/qos.py
+++ b/src/conf_mode/qos.py
@@ -23,6 +23,7 @@ from vyos.base import Warning
from vyos.config import Config
from vyos.configdep import set_dependents, call_dependents
from vyos.configdict import dict_merge
+from vyos.configverify import verify_interface_exists
from vyos.ifconfig import Section
from vyos.qos import CAKE
from vyos.qos import DropTail
@@ -37,7 +38,6 @@ from vyos.qos import RoundRobin
from vyos.qos import TrafficShaper
from vyos.qos import TrafficShaperHFSC
from vyos.utils.dict import dict_search_recursive
-from vyos.utils.network import interface_exists
from vyos.utils.process import run
from vyos import ConfigError
from vyos import airbag
@@ -215,11 +215,10 @@ def apply(qos):
return None
for interface, interface_config in qos['interface'].items():
- if not interface_exists(interface):
+ if not verify_interface_exists(interface, warning_only=True):
# When shaper is bound to a dialup (e.g. PPPoE) interface it is
# possible that it is yet not availbale when to QoS code runs.
- # Skip the configuration and inform the user
- Warning(f'Interface "{interface}" does not exist!')
+ # Skip the configuration and inform the user via warning_only=True
continue
for direction in ['egress', 'ingress']: